
# Type: has input


holds between a process and a continuant, where the continuant is an input into the process

URI: [biolink:has_input](https://w3id.org/biolink/vocab/has_input)


## Domain and Range

[Occurrent](Occurrent.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [has participant](has_participant.md)

## Children

 *  [molecular activity➞has input](molecular_activity_has_input.md)

## Used by

 * [ActivityAndBehavior](ActivityAndBehavior.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [EnvironmentalProcess](EnvironmentalProcess.md)
 * [MolecularActivity](MolecularActivity.md)
 * [Occurrent](Occurrent.md)
 * [Pathway](Pathway.md)
 * [Phenomenon](Phenomenon.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [Procedure](Procedure.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002233 |
|  | | SEMMEDDB:USES |
| **In Subsets:** | | translator_minimal |

